# vpn_exclude_sbs

This is a package for excluding DNSs from the VPN the PC connected to.

You can either pass a domain name to excluding, or a specifiec ip address.

# How to use ?

# 1. For excluding a url:
python -m -url < domain name >

# 2. For excluding a specifiec ip address:
python -m -ip < ip address >



